==> SoftwareAI-0.5.32-py3-none-any.whl: softwareai/CoreApp/_init_functions_.py <==
from softwareai.CoreApp.SoftwareAI.Functions.get_datetime_function import *
from softwareai.CoreApp.SoftwareAI.Functions.run_testes_function import *
from softwareai.CoreApp.SoftwareAI.Functions.upload_project_py_function import *
from softwareai.CoreApp.SoftwareAI.Functions.improve_code_function import *
from softwareai.CoreApp.SoftwareAI.Functions.review_pr_function import *
from softwareai.CoreApp.SoftwareAI.Functions.add_project_map_function import *
from softwareai.CoreApp.SoftwareAI.Functions.analyze_file_function import *
from softwareai.CoreApp.SoftwareAI.Functions.save_TXT_function import *
from softwareai.CoreApp.SoftwareAI.Functions.save_code_function import *
from softwareai.CoreApp.SoftwareAI.Functions.execute_py_function import *
from softwareai.CoreApp.SoftwareAI.Functions.update_readme_function import *
            
from softwareai.CoreApp.SoftwareAI.Functions.pegar_hora_function import *

from softwareai.CoreApp.SoftwareAI.Functions.autosave_function import *

from softwareai.CoreApp.SoftwareAI.Functions.autoupload_function import *
from softwareai.CoreApp.SoftwareAI.Functions.create_repo_function import *
from softwareai.CoreApp.SoftwareAI.Functions.autopullrequest import *
from softwareai.CoreApp.SoftwareAI.Functions.autoupdaterepo import *
from softwareai.CoreApp.SoftwareAI.Functions.autogetstructure import *
from softwareai.CoreApp.SoftwareAI.Functions.autogetfilecontent import *
from softwareai.CoreApp.SoftwareAI.Functions.checkcommentspr import *
from softwareai.CoreApp.SoftwareAI.Functions.Support.TicketProblem import *

==> SoftwareAI-0.5.44-py3-none-any.whl: softwareai/CoreApp/_init_functions_.py <==
from softwareai.CoreApp.SoftwareAI.Functions.get_datetime_function import *
from softwareai.CoreApp.SoftwareAI.Functions.run_testes_function import *
from softwareai.CoreApp.SoftwareAI.Functions.upload_project_py_function import *
from softwareai.CoreApp.SoftwareAI.Functions.improve_code_function import *
from softwareai.CoreApp.SoftwareAI.Functions.review_pr_function import *
from softwareai.CoreApp.SoftwareAI.Functions.add_project_map_function import *
from softwareai.CoreApp.SoftwareAI.Functions.analyze_file_function import *
from softwareai.CoreApp.SoftwareAI.Functions.save_TXT_function import *
from softwareai.CoreApp.SoftwareAI.Functions.save_code_function import *
from softwareai.CoreApp.SoftwareAI.Functions.execute_py_function import *
from softwareai.CoreApp.SoftwareAI.Functions.update_readme_function import *
            
from softwareai.CoreApp.SoftwareAI.Functions.pegar_hora_function import *

from softwareai.CoreApp.SoftwareAI.Functions.autosave_function import *

from softwareai.CoreApp.SoftwareAI.Functions.autoupload_function import *
from softwareai.CoreApp.SoftwareAI.Functions.create_repo_function import *
from softwareai.CoreApp.SoftwareAI.Functions.autopullrequest import *
from softwareai.CoreApp.SoftwareAI.Functions.autoupdaterepo import *
from softwareai.CoreApp.SoftwareAI.Functions.autogetstructure import *
from softwareai.CoreApp.SoftwareAI.Functions.autogetfilecontent import *
from softwareai.CoreApp.SoftwareAI.Functions.autocheckcommentspr import *
from softwareai.CoreApp.SoftwareAI.Functions.Software_Support.TicketProblem import *
from softwareai.CoreApp.SoftwareAI.Functions.Software_Technical_Support.AutoGetLoggerUser import *
from softwareai.CoreApp.SoftwareAI.Functions.Software_Development_Testing.AutoTestModule import *
